AttributionData class

Flutter representation of Android ChottuLink.AttributionData.

Constructors

AttributionData({String? attributionType, String? installId, required bool matchFound, String? matchType, String? shortUrl, String? clickedShortUrl, String? destinationUrl, String? destinationWithUtm, String? utmSource, String? utmMedium, String? utmCampaign, String? utmTerm, String? utmContent, required bool isAttributed})
const
AttributionData.fromMap(Map map)
factory

Properties

attributionType String?
final
clickedShortUrl String?
final
destinationUrl String?
final
destinationWithUtm String?
final
hashCode int
The hash code for this object.
no setterinherited
installId String?
final
isAttributed bool
final
matchFound bool
final
matchType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortUrl String?
final
utmCampaign String?
final
utmContent String?
final
utmMedium String?
final
utmSource String?
final
utmTerm String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited