ResolvedLink class

Constructors

ResolvedLink({String? link, String? shortLink, String? shortLinkRaw, bool? isDeferred})

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeferred bool?
final
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
getter/setter pair
shortLinkRaw String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited