CustomerMeta class

Flutter representation of Android ChottuLink.CustomerMeta.

This is a lightweight container that is converted to/from a platform-channel argument map.

Constructors

CustomerMeta({required String id, String? name, String? email, String? phone, String? emailSha256, String? phoneSha256})
const

Properties

email String?
final
emailSha256 String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String?
final
phone String?
final
phoneSha256 String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited