MethodChannelChottuLink class

An implementation of ChottuLinkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelChottuLink()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Actual
override
flush() Future<void>
override
getApiKey() Future<String>
override
getAppLinkData() Future<void>
override
getAppLinkDataFromUrl({required String shortUrl, dynamic onSuccess(ResolvedLink)?, dynamic onError(ChottuLinkError)?}) Future<void>
override
getAttributionData() Future<Map?>
Returns cached attribution data if available, otherwise null.
override
identify(Map<String, dynamic> meta) Future<void>
override
init({required String apiKey}) Future<String?>
override
isOptedOut() Future<bool>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optOut(bool optOut) Future<void>
override
toString() String
A string representation of this object.
inherited
trackConversion(Map<String, dynamic> meta) Future<void>
override
trackEvent(String eventName, Map<String, dynamic>? eventData) Future<void>
override
trackLead(Map<String, dynamic> meta) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited