- Inheritance
-
- Object
- PlatformInterface
- ChottuLinkPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDynamicLink({required CLDynamicLinkParameters parameters, dynamic onSuccess(String)?, dynamic onError(ChottuLinkError)?})
→ void
-
Method to create a dynamic link, accepting a map of parameters.
Should return a Future which is the short URL or null on error.
-
flush()
→ Future<void>
-
-
getApiKey()
→ Future<String>
-
-
getAppLinkData()
→ Future<void>
-
-
getAppLinkDataFromUrl({required String shortUrl, dynamic onSuccess(ResolvedLink)?, dynamic onError(ChottuLinkError)?})
→ Future<void>
-
-
getAttributionData()
→ Future<Map?>
-
Returns cached attribution data if available, otherwise
null.
-
identify(Map<String, dynamic> meta)
→ Future<void>
-
-
init({required String apiKey})
→ Future<String?>
-
-
isOptedOut()
→ Future<bool>
-
-
logout()
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
optOut(bool optOut)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
trackConversion(Map<String, dynamic> meta)
→ Future<void>
-
-
trackEvent(String eventName, Map<String, dynamic>? eventData)
→ Future<void>
-
-
trackLead(Map<String, dynamic> meta)
→ Future<void>
-