ConversionMeta class
Flutter representation of Android ChottuLink.ConversionMeta.
Constructors
Properties
- currency → String?
-
final
- eventName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
final
- productId → String?
-
final
- revenue → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited